[nautilus-actions: 31/45] Rename nact-assist-xxxx to nact-assistant-xxxx



commit 107353561bdc2b5f9d856db90c7a260340df3f25
Author: Pierre Wieser <pwieser trychlos org>
Date:   Tue Jul 28 23:50:19 2009 +0200

    Rename nact-assist-xxxx to nact-assistant-xxxx

 ChangeLog                                          |    6 +
 src/nact/Makefile.am                               |    8 +-
 src/nact/nact-assist-import.h                      |   71 --------
 ...act-assist-export.c => nact-assistant-export.c} |  174 ++++++++++----------
 ...act-assist-export.h => nact-assistant-export.h} |   40 +++---
 ...act-assist-import.c => nact-assistant-import.c} |  102 ++++++------
 src/nact/nact-assistant-import.h                   |   71 ++++++++
 src/nact/nact-imenubar.c                           |    8 +-
 8 files changed, 243 insertions(+), 237 deletions(-)
---
diff --git a/ChangeLog b/ChangeLog
index 5bcb368..9354389 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -7,6 +7,12 @@
 	* src/common/na-xml-names.h:
 	Define new FORMAT_GCONFSCHEMA format to create a schema.
 
+	* src/nact/nact-assist-export.{c,h}:
+	Renamed as src/nact/nact-assistant-export.{c,h}.
+
+	* src/nact/nact-assist-import.{c,h}:
+	Renamed as src/nact/nact-assistant-import.{c,h}.
+
 	* src/nact/nact-gconf-keys.h:
 	Renamed as src/common/na-xml-names.h.
 
diff --git a/src/nact/Makefile.am b/src/nact/Makefile.am
index c9bb868..b6e0990 100644
--- a/src/nact/Makefile.am
+++ b/src/nact/Makefile.am
@@ -51,10 +51,10 @@ nautilus_actions_config_tool_SOURCES = \
 	nact-application.h									\
 	nact-assistant.c									\
 	nact-assistant.h									\
-	nact-assist-export.c								\
-	nact-assist-export.h								\
-	nact-assist-import.c								\
-	nact-assist-import.h								\
+	nact-assistant-export.c								\
+	nact-assistant-export.h								\
+	nact-assistant-import.c								\
+	nact-assistant-import.h								\
 	nact-iaction-tab.c									\
 	nact-iaction-tab.h									\
 	nact-iactions-list.c								\
diff --git a/src/nact/nact-assist-export.c b/src/nact/nact-assistant-export.c
similarity index 79%
rename from src/nact/nact-assist-export.c
rename to src/nact/nact-assistant-export.c
index b236b0c..282e43f 100644
--- a/src/nact/nact-assist-export.c
+++ b/src/nact/nact-assistant-export.c
@@ -43,7 +43,7 @@
 
 #include "base-application.h"
 #include "nact-main-window.h"
-#include "nact-assist-export.h"
+#include "nact-assistant-export.h"
 #include "nact-iactions-list.h"
 #include "nact-iprefs.h"
 
@@ -70,12 +70,12 @@ enum {
 
 /* private class data
  */
-struct NactAssistExportClassPrivate {
+struct NactAssistantExportClassPrivate {
 };
 
 /* private instance data
  */
-struct NactAssistExportPrivate {
+struct NactAssistantExportPrivate {
 	gboolean        dispose_has_run;
 	NactMainWindow *main_window;
 	gchar          *uri;
@@ -88,13 +88,13 @@ struct NactAssistExportPrivate {
 static GObjectClass *st_parent_class = NULL;
 
 static GType             register_type( void );
-static void              class_init( NactAssistExportClass *klass );
+static void              class_init( NactAssistantExportClass *klass );
 static void              iactions_list_iface_init( NactIActionsListInterface *iface );
 static void              instance_init( GTypeInstance *instance, gpointer klass );
 static void              instance_dispose( GObject *application );
 static void              instance_finalize( GObject *application );
 
-static NactAssistExport *assist_new( BaseApplication *application );
+static NactAssistantExport *assist_new( BaseApplication *application );
 
 static gchar            *do_get_iprefs_window_id( NactWindow *window );
 static gchar            *do_get_dialog_name( BaseWindow *dialog );
@@ -105,42 +105,42 @@ static void              on_all_widgets_showed( BaseWindow *dialog );
 static void              on_apply( NactAssistant *window, GtkAssistant *assistant );
 static void              on_prepare( NactAssistant *window, GtkAssistant *assistant, GtkWidget *page );
 
-static void              assist_initial_load_intro( NactAssistExport *window, GtkAssistant *assistant );
-static void              assist_runtime_init_intro( NactAssistExport *window, GtkAssistant *assistant );
+static void              assist_initial_load_intro( NactAssistantExport *window, GtkAssistant *assistant );
+static void              assist_runtime_init_intro( NactAssistantExport *window, GtkAssistant *assistant );
 
-static void              assist_initial_load_actions_list( NactAssistExport *window, GtkAssistant *assistant );
-static void              assist_runtime_init_actions_list( NactAssistExport *window, GtkAssistant *assistant );
+static void              assist_initial_load_actions_list( NactAssistantExport *window, GtkAssistant *assistant );
+static void              assist_runtime_init_actions_list( NactAssistantExport *window, GtkAssistant *assistant );
 static void              on_actions_list_selection_changed( GtkTreeSelection *selection, gpointer user_data );
 
-static void              assist_initial_load_target_folder( NactAssistExport *window, GtkAssistant *assistant );
-static void              assist_runtime_init_target_folder( NactAssistExport *window, GtkAssistant *assistant );
-static GtkFileChooser   *get_folder_chooser( NactAssistExport *window );
+static void              assist_initial_load_target_folder( NactAssistantExport *window, GtkAssistant *assistant );
+static void              assist_runtime_init_target_folder( NactAssistantExport *window, GtkAssistant *assistant );
+static GtkFileChooser   *get_folder_chooser( NactAssistantExport *window );
 static void              on_folder_selection_changed( GtkFileChooser *chooser, gpointer user_data );
 static gboolean          is_writable_dir( const gchar *uri );
 
-static void              assist_initial_load_format( NactAssistExport *window, GtkAssistant *assistant );
-static void              assist_runtime_init_format( NactAssistExport *window, GtkAssistant *assistant );
+static void              assist_initial_load_format( NactAssistantExport *window, GtkAssistant *assistant );
+static void              assist_runtime_init_format( NactAssistantExport *window, GtkAssistant *assistant );
 static void              on_format_toggled( GtkToggleButton *button, gpointer user_data );
 static GtkWidget        *get_gconfschemav1_button( NactWindow *window );
 static GtkWidget        *get_gconfschemav2_button( NactWindow *window );
 static GtkWidget        *get_gconfdump_button( NactWindow *window );
 
-static void              assist_initial_load_confirm( NactAssistExport *window, GtkAssistant *assistant );
-static void              assist_runtime_init_confirm( NactAssistExport *window, GtkAssistant *assistant );
-static void              assist_prepare_confirm( NactAssistExport *window, GtkAssistant *assistant, GtkWidget *page );
+static void              assist_initial_load_confirm( NactAssistantExport *window, GtkAssistant *assistant );
+static void              assist_runtime_init_confirm( NactAssistantExport *window, GtkAssistant *assistant );
+static void              assist_prepare_confirm( NactAssistantExport *window, GtkAssistant *assistant, GtkWidget *page );
 
-static void              assist_initial_load_exportdone( NactAssistExport *window, GtkAssistant *assistant );
-static void              assist_runtime_init_exportdone( NactAssistExport *window, GtkAssistant *assistant );
-static void              assist_prepare_exportdone( NactAssistExport *window, GtkAssistant *assistant, GtkWidget *page );
+static void              assist_initial_load_exportdone( NactAssistantExport *window, GtkAssistant *assistant );
+static void              assist_runtime_init_exportdone( NactAssistantExport *window, GtkAssistant *assistant );
+static void              assist_prepare_exportdone( NactAssistantExport *window, GtkAssistant *assistant, GtkWidget *page );
 
-static void              do_export( NactAssistExport *window );
+static void              do_export( NactAssistantExport *window );
 
 #ifdef NA_MAINTAINER_MODE
-static void              dump( NactAssistExport *window );
+static void              dump( NactAssistantExport *window );
 #endif
 
 GType
-nact_assist_export_get_type( void )
+nact_assistant_export_get_type( void )
 {
 	static GType window_type = 0;
 
@@ -154,22 +154,22 @@ nact_assist_export_get_type( void )
 static GType
 register_type( void )
 {
-	static const gchar *thisfn = "nact_assist_export_register_type";
+	static const gchar *thisfn = "nact_assistant_export_register_type";
 	g_debug( "%s", thisfn );
 
 	static GTypeInfo info = {
-		sizeof( NactAssistExportClass ),
+		sizeof( NactAssistantExportClass ),
 		( GBaseInitFunc ) NULL,
 		( GBaseFinalizeFunc ) NULL,
 		( GClassInitFunc ) class_init,
 		NULL,
 		NULL,
-		sizeof( NactAssistExport ),
+		sizeof( NactAssistantExport ),
 		0,
 		( GInstanceInitFunc ) instance_init
 	};
 
-	GType type = g_type_register_static( NACT_ASSISTANT_TYPE, "NactAssistExport", &info, 0 );
+	GType type = g_type_register_static( NACT_ASSISTANT_TYPE, "NactAssistantExport", &info, 0 );
 
 	/* implement IActionsList interface
 	 */
@@ -185,9 +185,9 @@ register_type( void )
 }
 
 static void
-class_init( NactAssistExportClass *klass )
+class_init( NactAssistantExportClass *klass )
 {
-	static const gchar *thisfn = "nact_assist_export_class_init";
+	static const gchar *thisfn = "nact_assistant_export_class_init";
 	g_debug( "%s: klass=%p", thisfn, klass );
 
 	st_parent_class = g_type_class_peek_parent( klass );
@@ -196,7 +196,7 @@ class_init( NactAssistExportClass *klass )
 	object_class->dispose = instance_dispose;
 	object_class->finalize = instance_finalize;
 
-	klass->private = g_new0( NactAssistExportClassPrivate, 1 );
+	klass->private = g_new0( NactAssistantExportClassPrivate, 1 );
 
 	BaseWindowClass *base_class = BASE_WINDOW_CLASS( klass );
 	base_class->get_toplevel_name = do_get_dialog_name;
@@ -215,7 +215,7 @@ class_init( NactAssistExportClass *klass )
 static void
 iactions_list_iface_init( NactIActionsListInterface *iface )
 {
-	static const gchar *thisfn = "nact_assist_export_iactions_list_iface_init";
+	static const gchar *thisfn = "nact_assistant_export_iactions_list_iface_init";
 	g_debug( "%s: iface=%p", thisfn, iface );
 
 	iface->get_actions = get_actions;
@@ -225,13 +225,13 @@ iactions_list_iface_init( NactIActionsListInterface *iface )
 static void
 instance_init( GTypeInstance *instance, gpointer klass )
 {
-	static const gchar *thisfn = "nact_assist_export_instance_init";
+	static const gchar *thisfn = "nact_assistant_export_instance_init";
 	g_debug( "%s: instance=%p, klass=%p", thisfn, instance, klass );
 
-	g_assert( NACT_IS_ASSIST_EXPORT( instance ));
-	NactAssistExport *self = NACT_ASSIST_EXPORT( instance );
+	g_assert( NACT_IS_ASSISTANT_EXPORT( instance ));
+	NactAssistantExport *self = NACT_ASSISTANT_EXPORT( instance );
 
-	self->private = g_new0( NactAssistExportPrivate, 1 );
+	self->private = g_new0( NactAssistantExportPrivate, 1 );
 
 	self->private->dispose_has_run = FALSE;
 	self->private->fnames = NULL;
@@ -241,11 +241,11 @@ instance_init( GTypeInstance *instance, gpointer klass )
 static void
 instance_dispose( GObject *window )
 {
-	static const gchar *thisfn = "nact_assist_export_instance_dispose";
+	static const gchar *thisfn = "nact_assistant_export_instance_dispose";
 	g_debug( "%s: window=%p", thisfn, window );
 
-	g_assert( NACT_IS_ASSIST_EXPORT( window ));
-	NactAssistExport *self = NACT_ASSIST_EXPORT( window );
+	g_assert( NACT_IS_ASSISTANT_EXPORT( window ));
+	NactAssistantExport *self = NACT_ASSISTANT_EXPORT( window );
 
 	if( !self->private->dispose_has_run ){
 
@@ -259,11 +259,11 @@ instance_dispose( GObject *window )
 static void
 instance_finalize( GObject *window )
 {
-	static const gchar *thisfn = "nact_assist_export_instance_finalize";
+	static const gchar *thisfn = "nact_assistant_export_instance_finalize";
 	g_debug( "%s: window=%p", thisfn, window );
 
-	g_assert( NACT_IS_ASSIST_EXPORT( window ));
-	NactAssistExport *self = ( NactAssistExport * ) window;
+	g_assert( NACT_IS_ASSISTANT_EXPORT( window ));
+	NactAssistantExport *self = ( NactAssistantExport * ) window;
 
 	g_free( self->private->uri );
 	na_utils_free_string_list( self->private->fnames );
@@ -277,10 +277,10 @@ instance_finalize( GObject *window )
 	}
 }
 
-static NactAssistExport *
+static NactAssistantExport *
 assist_new( BaseApplication *application )
 {
-	return( g_object_new( NACT_ASSIST_EXPORT_TYPE, PROP_WINDOW_APPLICATION_STR, application, NULL ));
+	return( g_object_new( NACT_ASSISTANT_EXPORT_TYPE, PROP_WINDOW_APPLICATION_STR, application, NULL ));
 }
 
 /**
@@ -289,11 +289,11 @@ assist_new( BaseApplication *application )
  * @main: the main window of the application.
  */
 void
-nact_assist_export_run( NactWindow *main_window )
+nact_assistant_export_run( NactWindow *main_window )
 {
 	BaseApplication *appli = BASE_APPLICATION( base_window_get_application( BASE_WINDOW( main_window )));
 
-	NactAssistExport *assist = assist_new( appli );
+	NactAssistantExport *assist = assist_new( appli );
 	g_object_set( G_OBJECT( assist ), PROP_WINDOW_PARENT_STR, main_window, NULL );
 
 	assist->private->main_window = NACT_MAIN_WINDOW( main_window );
@@ -316,13 +316,13 @@ do_get_dialog_name( BaseWindow *dialog )
 static GSList *
 get_actions( NactWindow *window )
 {
-	return( nact_main_window_get_actions( NACT_ASSIST_EXPORT( window )->private->main_window ));
+	return( nact_main_window_get_actions( NACT_ASSISTANT_EXPORT( window )->private->main_window ));
 }
 
 static void
 on_initial_load_dialog( BaseWindow *dialog )
 {
-	static const gchar *thisfn = "nact_assist_export_on_initial_load_dialog";
+	static const gchar *thisfn = "nact_assistant_export_on_initial_load_dialog";
 
 	/* call parent class at the very beginning */
 	if( BASE_WINDOW_CLASS( st_parent_class )->initial_load_toplevel ){
@@ -330,8 +330,8 @@ on_initial_load_dialog( BaseWindow *dialog )
 	}
 
 	g_debug( "%s: dialog=%p", thisfn, dialog );
-	g_assert( NACT_IS_ASSIST_EXPORT( dialog ));
-	NactAssistExport *window = NACT_ASSIST_EXPORT( dialog );
+	g_assert( NACT_IS_ASSISTANT_EXPORT( dialog ));
+	NactAssistantExport *window = NACT_ASSISTANT_EXPORT( dialog );
 
 	GtkAssistant *assistant = GTK_ASSISTANT( base_window_get_toplevel_dialog( dialog ));
 
@@ -346,7 +346,7 @@ on_initial_load_dialog( BaseWindow *dialog )
 static void
 on_runtime_init_dialog( BaseWindow *dialog )
 {
-	static const gchar *thisfn = "nact_assist_export_on_runtime_init_dialog";
+	static const gchar *thisfn = "nact_assistant_export_on_runtime_init_dialog";
 
 	/* call parent class at the very beginning */
 	if( BASE_WINDOW_CLASS( st_parent_class )->runtime_init_toplevel ){
@@ -354,8 +354,8 @@ on_runtime_init_dialog( BaseWindow *dialog )
 	}
 
 	g_debug( "%s: dialog=%p", thisfn, dialog );
-	g_assert( NACT_IS_ASSIST_EXPORT( dialog ));
-	NactAssistExport *window = NACT_ASSIST_EXPORT( dialog );
+	g_assert( NACT_IS_ASSISTANT_EXPORT( dialog ));
+	NactAssistantExport *window = NACT_ASSISTANT_EXPORT( dialog );
 
 	GtkAssistant *assistant = GTK_ASSISTANT( base_window_get_toplevel_dialog( dialog ));
 
@@ -386,25 +386,25 @@ on_all_widgets_showed( BaseWindow *dialog )
 static void
 on_apply( NactAssistant *window, GtkAssistant *assistant )
 {
-	static const gchar *thisfn = "nact_assist_export_on_apply";
+	static const gchar *thisfn = "nact_assistant_export_on_apply";
 	g_debug( "%s: window=%p, assistant=%p", thisfn, window, assistant );
 }
 
 static void
 on_prepare( NactAssistant *window, GtkAssistant *assistant, GtkWidget *page )
 {
-	/*static const gchar *thisfn = "nact_assist_export_on_prepare";
+	/*static const gchar *thisfn = "nact_assistant_export_on_prepare";
 	g_debug( "%s: window=%p, assistant=%p, page=%p", thisfn, window, assistant, page );*/
 
 	GtkAssistantPageType type = gtk_assistant_get_page_type( assistant, page );
 
 	switch( type ){
 		case GTK_ASSISTANT_PAGE_CONFIRM:
-			assist_prepare_confirm( NACT_ASSIST_EXPORT( window ), assistant, page );
+			assist_prepare_confirm( NACT_ASSISTANT_EXPORT( window ), assistant, page );
 			break;
 
 		case GTK_ASSISTANT_PAGE_SUMMARY:
-			assist_prepare_exportdone( NACT_ASSIST_EXPORT( window ), assistant, page );
+			assist_prepare_exportdone( NACT_ASSISTANT_EXPORT( window ), assistant, page );
 			break;
 
 		default:
@@ -413,14 +413,14 @@ on_prepare( NactAssistant *window, GtkAssistant *assistant, GtkWidget *page )
 }
 
 static void
-assist_initial_load_intro( NactAssistExport *window, GtkAssistant *assistant )
+assist_initial_load_intro( NactAssistantExport *window, GtkAssistant *assistant )
 {
 }
 
 static void
-assist_runtime_init_intro( NactAssistExport *window, GtkAssistant *assistant )
+assist_runtime_init_intro( NactAssistantExport *window, GtkAssistant *assistant )
 {
-	static const gchar *thisfn = "nact_assist_export_runtime_init_intro";
+	static const gchar *thisfn = "nact_assistant_export_runtime_init_intro";
 	g_debug( "%s: window=%p, assistant=%p", thisfn, window, assistant );
 
 	GtkWidget *content = gtk_assistant_get_nth_page( assistant, ASSIST_PAGE_INTRO );
@@ -428,7 +428,7 @@ assist_runtime_init_intro( NactAssistExport *window, GtkAssistant *assistant )
 }
 
 static void
-assist_initial_load_actions_list( NactAssistExport *window, GtkAssistant *assistant )
+assist_initial_load_actions_list( NactAssistantExport *window, GtkAssistant *assistant )
 {
 	g_assert( NACT_IS_IACTIONS_LIST( window ));
 	nact_iactions_list_initial_load( NACT_WINDOW( window ));
@@ -438,7 +438,7 @@ assist_initial_load_actions_list( NactAssistExport *window, GtkAssistant *assist
 }
 
 static void
-assist_runtime_init_actions_list( NactAssistExport *window, GtkAssistant *assistant )
+assist_runtime_init_actions_list( NactAssistantExport *window, GtkAssistant *assistant )
 {
 	nact_iactions_list_runtime_init( NACT_WINDOW( window ));
 
@@ -449,10 +449,10 @@ assist_runtime_init_actions_list( NactAssistExport *window, GtkAssistant *assist
 static void
 on_actions_list_selection_changed( GtkTreeSelection *selection, gpointer user_data )
 {
-	/*static const gchar *thisfn = "nact_assist_export_on_actions_list_selection_changed";
+	/*static const gchar *thisfn = "nact_assistant_export_on_actions_list_selection_changed";
 	g_debug( "%s: selection=%p, user_data=%p", thisfn, selection, user_data );*/
 
-	g_assert( NACT_IS_ASSIST_EXPORT( user_data ));
+	g_assert( NACT_IS_ASSISTANT_EXPORT( user_data ));
 	GtkAssistant *assistant = GTK_ASSISTANT( base_window_get_toplevel_dialog( BASE_WINDOW( user_data )));
 	gint pos = gtk_assistant_get_current_page( assistant );
 	if( pos == ASSIST_PAGE_ACTIONS_SELECTION ){
@@ -466,7 +466,7 @@ on_actions_list_selection_changed( GtkTreeSelection *selection, gpointer user_da
 }
 
 static void
-assist_initial_load_target_folder( NactAssistExport *window, GtkAssistant *assistant )
+assist_initial_load_target_folder( NactAssistantExport *window, GtkAssistant *assistant )
 {
 	GtkFileChooser *chooser = get_folder_chooser( window );
 	gtk_file_chooser_set_action( GTK_FILE_CHOOSER( chooser ), GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER );
@@ -474,7 +474,7 @@ assist_initial_load_target_folder( NactAssistExport *window, GtkAssistant *assis
 }
 
 static void
-assist_runtime_init_target_folder( NactAssistExport *window, GtkAssistant *assistant )
+assist_runtime_init_target_folder( NactAssistantExport *window, GtkAssistant *assistant )
 {
 	GtkFileChooser *chooser = get_folder_chooser( window );
 	gtk_file_chooser_unselect_all( chooser );
@@ -492,7 +492,7 @@ assist_runtime_init_target_folder( NactAssistExport *window, GtkAssistant *assis
 }
 
 static GtkFileChooser *
-get_folder_chooser( NactAssistExport *window )
+get_folder_chooser( NactAssistantExport *window )
 {
 	return( GTK_FILE_CHOOSER( base_window_get_widget( BASE_WINDOW( window ), "ExportFolderChooser" )));
 }
@@ -505,10 +505,10 @@ get_folder_chooser( NactAssistExport *window )
 static void
 on_folder_selection_changed( GtkFileChooser *chooser, gpointer user_data )
 {
-	static const gchar *thisfn = "nact_assist_export_on_folder_selection_changed";
+	static const gchar *thisfn = "nact_assistant_export_on_folder_selection_changed";
 	g_debug( "%s: chooser=%p, user_data=%p", thisfn, chooser, user_data );
 
-	g_assert( NACT_IS_ASSIST_EXPORT( user_data ));
+	g_assert( NACT_IS_ASSISTANT_EXPORT( user_data ));
 	GtkAssistant *assistant = GTK_ASSISTANT( base_window_get_toplevel_dialog( BASE_WINDOW( user_data )));
 	gint pos = gtk_assistant_get_current_page( assistant );
 	if( pos == ASSIST_PAGE_FOLDER_SELECTION ){
@@ -518,7 +518,7 @@ on_folder_selection_changed( GtkFileChooser *chooser, gpointer user_data )
 		gboolean enabled = ( uri && strlen( uri ) && is_writable_dir( uri ));
 
 		if( enabled ){
-			NactAssistExport *assist = NACT_ASSIST_EXPORT( user_data );
+			NactAssistantExport *assist = NACT_ASSISTANT_EXPORT( user_data );
 			g_free( assist->private->uri );
 			assist->private->uri = g_strdup( uri );
 			nact_iprefs_save_export_folder_uri( NACT_WINDOW( user_data ), uri );
@@ -535,7 +535,7 @@ on_folder_selection_changed( GtkFileChooser *chooser, gpointer user_data )
 static gboolean
 is_writable_dir( const gchar *uri )
 {
-	static const gchar *thisfn = "nact_assist_export_is_writable_dir";
+	static const gchar *thisfn = "nact_assistant_export_is_writable_dir";
 
 	if( !uri || !strlen( uri )){
 		return( FALSE );
@@ -571,12 +571,12 @@ is_writable_dir( const gchar *uri )
 }
 
 static void
-assist_initial_load_format( NactAssistExport *window, GtkAssistant *assistant )
+assist_initial_load_format( NactAssistantExport *window, GtkAssistant *assistant )
 {
 }
 
 static void
-assist_runtime_init_format( NactAssistExport *window, GtkAssistant *assistant )
+assist_runtime_init_format( NactAssistantExport *window, GtkAssistant *assistant )
 {
 	GtkWidget *button = get_gconfschemav1_button( NACT_WINDOW( window ));
 	nact_window_signal_connect( NACT_WINDOW( window ), G_OBJECT( button ), "toggled", G_CALLBACK( on_format_toggled ));
@@ -600,13 +600,13 @@ on_format_toggled( GtkToggleButton *button, gpointer user_data )
 	NactWindow *window = NACT_WINDOW( user_data );
 
 	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( get_gconfschemav1_button( window )))){
-		NACT_ASSIST_EXPORT( window )->private->format = FORMAT_GCONFSCHEMAFILE_V1;
+		NACT_ASSISTANT_EXPORT( window )->private->format = FORMAT_GCONFSCHEMAFILE_V1;
 
 	} else if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( get_gconfschemav2_button( window )))){
-		NACT_ASSIST_EXPORT( window )->private->format = FORMAT_GCONFSCHEMAFILE_V2;
+		NACT_ASSISTANT_EXPORT( window )->private->format = FORMAT_GCONFSCHEMAFILE_V2;
 
 	} else if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( get_gconfdump_button( window )))){
-		NACT_ASSIST_EXPORT( window )->private->format = FORMAT_GCONFENTRY;
+		NACT_ASSISTANT_EXPORT( window )->private->format = FORMAT_GCONFENTRY;
 	}
 }
 
@@ -629,19 +629,19 @@ get_gconfdump_button( NactWindow *window )
 }
 
 static void
-assist_initial_load_confirm( NactAssistExport *window, GtkAssistant *assistant )
+assist_initial_load_confirm( NactAssistantExport *window, GtkAssistant *assistant )
 {
 }
 
 static void
-assist_runtime_init_confirm( NactAssistExport *window, GtkAssistant *assistant )
+assist_runtime_init_confirm( NactAssistantExport *window, GtkAssistant *assistant )
 {
 }
 
 static void
-assist_prepare_confirm( NactAssistExport *window, GtkAssistant *assistant, GtkWidget *page )
+assist_prepare_confirm( NactAssistantExport *window, GtkAssistant *assistant, GtkWidget *page )
 {
-	static const gchar *thisfn = "nact_assist_export_prepare_confirm";
+	static const gchar *thisfn = "nact_assistant_export_prepare_confirm";
 	g_debug( "%s: window=%p, assistant=%p, page=%p", thisfn, window, assistant, page );
 
 #ifdef NA_MAINTAINER_MODE
@@ -701,19 +701,19 @@ assist_prepare_confirm( NactAssistExport *window, GtkAssistant *assistant, GtkWi
 }
 
 static void
-assist_initial_load_exportdone( NactAssistExport *window, GtkAssistant *assistant )
+assist_initial_load_exportdone( NactAssistantExport *window, GtkAssistant *assistant )
 {
 }
 
 static void
-assist_runtime_init_exportdone( NactAssistExport *window, GtkAssistant *assistant )
+assist_runtime_init_exportdone( NactAssistantExport *window, GtkAssistant *assistant )
 {
 }
 
 static void
-assist_prepare_exportdone( NactAssistExport *window, GtkAssistant *assistant, GtkWidget *page )
+assist_prepare_exportdone( NactAssistantExport *window, GtkAssistant *assistant, GtkWidget *page )
 {
-	static const gchar *thisfn = "nact_assist_export_prepare_exportdone";
+	static const gchar *thisfn = "nact_assistant_export_prepare_exportdone";
 	g_debug( "%s: window=%p, assistant=%p, page=%p", thisfn, window, assistant, page );
 
 	do_export( window );
@@ -760,9 +760,9 @@ assist_prepare_exportdone( NactAssistExport *window, GtkAssistant *assistant, Gt
 }
 
 static void
-do_export( NactAssistExport *window )
+do_export( NactAssistantExport *window )
 {
-	static const gchar *thisfn = "nact_assist_export_do_export";
+	static const gchar *thisfn = "nact_assistant_export_do_export";
 	g_debug( "%s: window=%p", thisfn, window );
 
 	GSList *actions = nact_iactions_list_get_selected_actions( NACT_WINDOW( window ));
@@ -809,9 +809,9 @@ do_export( NactAssistExport *window )
 
 #ifdef NA_MAINTAINER_MODE
 static void
-dump( NactAssistExport *window )
+dump( NactAssistantExport *window )
 {
-	static const gchar *thisfn = "nact_assist_export_dump";
+	static const gchar *thisfn = "nact_assistant_export_dump";
 	g_debug( "%s:          window=%p", thisfn, window );
 	g_debug( "%s:         private=%p", thisfn, window->private );
 	g_debug( "%s: dispose_has_run=%s", thisfn, window->private->dispose_has_run ? "True":"False" );
diff --git a/src/nact/nact-assist-import.c b/src/nact/nact-assistant-import.c
similarity index 78%
rename from src/nact/nact-assist-import.c
rename to src/nact/nact-assistant-import.c
index 0fb4665..fc45053 100644
--- a/src/nact/nact-assist-import.c
+++ b/src/nact/nact-assistant-import.c
@@ -41,7 +41,7 @@
 #include <common/na-utils.h>
 
 #include "base-application.h"
-#include "nact-assist-import.h"
+#include "nact-assistant-import.h"
 #include "nact-xml-reader.h"
 #include "nact-iprefs.h"
 
@@ -71,12 +71,12 @@ typedef struct {
 
 /* private class data
  */
-struct NactAssistImportClassPrivate {
+struct NactAssistantImportClassPrivate {
 };
 
 /* private instance data
  */
-struct NactAssistImportPrivate {
+struct NactAssistantImportPrivate {
 	gboolean  dispose_has_run;
 	GSList   *results;
 	GSList   *actions;
@@ -85,28 +85,28 @@ struct NactAssistImportPrivate {
 static GObjectClass *st_parent_class = NULL;
 
 static GType             register_type( void );
-static void              class_init( NactAssistImportClass *klass );
+static void              class_init( NactAssistantImportClass *klass );
 static void              instance_init( GTypeInstance *instance, gpointer klass );
 static void              instance_dispose( GObject *application );
 static void              instance_finalize( GObject *application );
 
-static NactAssistImport *assist_new( BaseApplication *application );
+static NactAssistantImport *assist_new( BaseApplication *application );
 
 static gchar            *do_get_iprefs_window_id( NactWindow *window );
 static gchar            *do_get_dialog_name( BaseWindow *dialog );
 static void              on_runtime_init_dialog( BaseWindow *dialog );
-static void              runtime_init_intro( NactAssistImport *window, GtkAssistant *assistant );
-static void              runtime_init_file_selector( NactAssistImport *window, GtkAssistant *assistant );
+static void              runtime_init_intro( NactAssistantImport *window, GtkAssistant *assistant );
+static void              runtime_init_file_selector( NactAssistantImport *window, GtkAssistant *assistant );
 static void              on_file_selection_changed( GtkFileChooser *chooser, gpointer user_data );
 static gboolean          has_readable_files( GSList *uris );
 static void              on_prepare( NactAssistant *window, GtkAssistant *assistant, GtkWidget *page );
-static void              prepare_confirm( NactAssistImport *window, GtkAssistant *assistant, GtkWidget *page );
-static void              prepare_importdone( NactAssistImport *window, GtkAssistant *assistant, GtkWidget *page );
-static void              do_import( NactAssistImport *window, GtkAssistant *assistant );
+static void              prepare_confirm( NactAssistantImport *window, GtkAssistant *assistant, GtkWidget *page );
+static void              prepare_importdone( NactAssistantImport *window, GtkAssistant *assistant, GtkWidget *page );
+static void              do_import( NactAssistantImport *window, GtkAssistant *assistant );
 static void              free_results( GSList *list );
 
 GType
-nact_assist_import_get_type( void )
+nact_assistant_import_get_type( void )
 {
 	static GType window_type = 0;
 
@@ -120,30 +120,30 @@ nact_assist_import_get_type( void )
 static GType
 register_type( void )
 {
-	static const gchar *thisfn = "nact_assist_import_register_type";
+	static const gchar *thisfn = "nact_assistant_import_register_type";
 	g_debug( "%s", thisfn );
 
 	static GTypeInfo info = {
-		sizeof( NactAssistImportClass ),
+		sizeof( NactAssistantImportClass ),
 		( GBaseInitFunc ) NULL,
 		( GBaseFinalizeFunc ) NULL,
 		( GClassInitFunc ) class_init,
 		NULL,
 		NULL,
-		sizeof( NactAssistImport ),
+		sizeof( NactAssistantImport ),
 		0,
 		( GInstanceInitFunc ) instance_init
 	};
 
-	GType type = g_type_register_static( NACT_ASSISTANT_TYPE, "NactAssistImport", &info, 0 );
+	GType type = g_type_register_static( NACT_ASSISTANT_TYPE, "NactAssistantImport", &info, 0 );
 
 	return( type );
 }
 
 static void
-class_init( NactAssistImportClass *klass )
+class_init( NactAssistantImportClass *klass )
 {
-	static const gchar *thisfn = "nact_assist_import_class_init";
+	static const gchar *thisfn = "nact_assistant_import_class_init";
 	g_debug( "%s: klass=%p", thisfn, klass );
 
 	st_parent_class = g_type_class_peek_parent( klass );
@@ -152,7 +152,7 @@ class_init( NactAssistImportClass *klass )
 	object_class->dispose = instance_dispose;
 	object_class->finalize = instance_finalize;
 
-	klass->private = g_new0( NactAssistImportClassPrivate, 1 );
+	klass->private = g_new0( NactAssistantImportClassPrivate, 1 );
 
 	BaseWindowClass *base_class = BASE_WINDOW_CLASS( klass );
 	base_class->get_toplevel_name = do_get_dialog_name;
@@ -168,13 +168,13 @@ class_init( NactAssistImportClass *klass )
 static void
 instance_init( GTypeInstance *instance, gpointer klass )
 {
-	static const gchar *thisfn = "nact_assist_import_instance_init";
+	static const gchar *thisfn = "nact_assistant_import_instance_init";
 	g_debug( "%s: instance=%p, klass=%p", thisfn, instance, klass );
 
-	g_assert( NACT_IS_ASSIST_IMPORT( instance ));
-	NactAssistImport *self = NACT_ASSIST_IMPORT( instance );
+	g_assert( NACT_IS_ASSISTANT_IMPORT( instance ));
+	NactAssistantImport *self = NACT_ASSISTANT_IMPORT( instance );
 
-	self->private = g_new0( NactAssistImportPrivate, 1 );
+	self->private = g_new0( NactAssistantImportPrivate, 1 );
 
 	self->private->dispose_has_run = FALSE;
 	self->private->results = NULL;
@@ -183,11 +183,11 @@ instance_init( GTypeInstance *instance, gpointer klass )
 static void
 instance_dispose( GObject *window )
 {
-	static const gchar *thisfn = "nact_assist_import_instance_dispose";
+	static const gchar *thisfn = "nact_assistant_import_instance_dispose";
 	g_debug( "%s: window=%p", thisfn, window );
 
-	g_assert( NACT_IS_ASSIST_IMPORT( window ));
-	NactAssistImport *self = NACT_ASSIST_IMPORT( window );
+	g_assert( NACT_IS_ASSISTANT_IMPORT( window ));
+	NactAssistantImport *self = NACT_ASSISTANT_IMPORT( window );
 
 	if( !self->private->dispose_has_run ){
 
@@ -201,11 +201,11 @@ instance_dispose( GObject *window )
 static void
 instance_finalize( GObject *window )
 {
-	static const gchar *thisfn = "nact_assist_import_instance_finalize";
+	static const gchar *thisfn = "nact_assistant_import_instance_finalize";
 	g_debug( "%s: window=%p", thisfn, window );
 
-	g_assert( NACT_IS_ASSIST_IMPORT( window ));
-	NactAssistImport *self = ( NactAssistImport * ) window;
+	g_assert( NACT_IS_ASSISTANT_IMPORT( window ));
+	NactAssistantImport *self = ( NactAssistantImport * ) window;
 
 	free_results( self->private->results );
 
@@ -217,10 +217,10 @@ instance_finalize( GObject *window )
 	}
 }
 
-static NactAssistImport *
+static NactAssistantImport *
 assist_new( BaseApplication *application )
 {
-	return( g_object_new( NACT_ASSIST_IMPORT_TYPE, PROP_WINDOW_APPLICATION_STR, application, NULL ));
+	return( g_object_new( NACT_ASSISTANT_IMPORT_TYPE, PROP_WINDOW_APPLICATION_STR, application, NULL ));
 }
 
 /**
@@ -229,11 +229,11 @@ assist_new( BaseApplication *application )
  * @main: the main window of the application.
  */
 GSList *
-nact_assist_import_run( NactWindow *main_window )
+nact_assistant_import_run( NactWindow *main_window )
 {
 	BaseApplication *appli = BASE_APPLICATION( base_window_get_application( BASE_WINDOW( main_window )));
 
-	NactAssistImport *assist = assist_new( appli );
+	NactAssistantImport *assist = assist_new( appli );
 
 	g_object_set( G_OBJECT( assist ), PROP_WINDOW_PARENT_STR, main_window, NULL );
 
@@ -257,7 +257,7 @@ do_get_dialog_name( BaseWindow *dialog )
 static void
 on_runtime_init_dialog( BaseWindow *dialog )
 {
-	static const gchar *thisfn = "nact_assist_import_on_runtime_init_dialog";
+	static const gchar *thisfn = "nact_assistant_import_on_runtime_init_dialog";
 
 	/* call parent class at the very beginning */
 	if( BASE_WINDOW_CLASS( st_parent_class )->runtime_init_toplevel ){
@@ -265,8 +265,8 @@ on_runtime_init_dialog( BaseWindow *dialog )
 	}
 
 	g_debug( "%s: dialog=%p", thisfn, dialog );
-	g_assert( NACT_IS_ASSIST_IMPORT( dialog ));
-	NactAssistImport *window = NACT_ASSIST_IMPORT( dialog );
+	g_assert( NACT_IS_ASSISTANT_IMPORT( dialog ));
+	NactAssistantImport *window = NACT_ASSISTANT_IMPORT( dialog );
 
 	GtkAssistant *assistant = GTK_ASSISTANT( base_window_get_toplevel_dialog( dialog ));
 
@@ -275,9 +275,9 @@ on_runtime_init_dialog( BaseWindow *dialog )
 }
 
 static void
-runtime_init_intro( NactAssistImport *window, GtkAssistant *assistant )
+runtime_init_intro( NactAssistantImport *window, GtkAssistant *assistant )
 {
-	static const gchar *thisfn = "nact_assist_import_runtime_init_intro";
+	static const gchar *thisfn = "nact_assistant_import_runtime_init_intro";
 
 	GtkWidget *content = gtk_assistant_get_nth_page( assistant, ASSIST_PAGE_INTRO );
 
@@ -287,9 +287,9 @@ runtime_init_intro( NactAssistImport *window, GtkAssistant *assistant )
 }
 
 static void
-runtime_init_file_selector( NactAssistImport *window, GtkAssistant *assistant )
+runtime_init_file_selector( NactAssistantImport *window, GtkAssistant *assistant )
 {
-	static const gchar *thisfn = "nact_assist_import_runtime_init_file_selector";
+	static const gchar *thisfn = "nact_assistant_import_runtime_init_file_selector";
 
 	GtkWidget *chooser = gtk_assistant_get_nth_page( assistant, ASSIST_PAGE_FILES_SELECTION );
 
@@ -309,10 +309,10 @@ runtime_init_file_selector( NactAssistImport *window, GtkAssistant *assistant )
 static void
 on_file_selection_changed( GtkFileChooser *chooser, gpointer user_data )
 {
-	/*static const gchar *thisfn = "nact_assist_import_on_file_selection_changed";
+	/*static const gchar *thisfn = "nact_assistant_import_on_file_selection_changed";
 	g_debug( "%s: chooser=%p, user_data=%p", thisfn, chooser, user_data );*/
 
-	g_assert( NACT_IS_ASSIST_IMPORT( user_data ));
+	g_assert( NACT_IS_ASSISTANT_IMPORT( user_data ));
 	GtkAssistant *assistant = GTK_ASSISTANT( base_window_get_toplevel_dialog( BASE_WINDOW( user_data )));
 	gint pos = gtk_assistant_get_current_page( assistant );
 	if( pos == ASSIST_PAGE_FILES_SELECTION ){
@@ -337,7 +337,7 @@ on_file_selection_changed( GtkFileChooser *chooser, gpointer user_data )
 static gboolean
 has_readable_files( GSList *uris )
 {
-	static const gchar *thisfn = "nact_assist_import_has_readable_files";
+	static const gchar *thisfn = "nact_assistant_import_has_readable_files";
 
 	GSList *iuri;
 	int readables = 0;
@@ -386,18 +386,18 @@ has_readable_files( GSList *uris )
 static void
 on_prepare( NactAssistant *window, GtkAssistant *assistant, GtkWidget *page )
 {
-	static const gchar *thisfn = "nact_assist_import_on_prepare";
+	static const gchar *thisfn = "nact_assistant_import_on_prepare";
 	g_debug( "%s: window=%p, assistant=%p, page=%p", thisfn, window, assistant, page );
 
 	GtkAssistantPageType type = gtk_assistant_get_page_type( assistant, page );
 
 	switch( type ){
 		case GTK_ASSISTANT_PAGE_CONFIRM:
-			prepare_confirm( NACT_ASSIST_IMPORT( window ), assistant, page );
+			prepare_confirm( NACT_ASSISTANT_IMPORT( window ), assistant, page );
 			break;
 
 		case GTK_ASSISTANT_PAGE_SUMMARY:
-			prepare_importdone( NACT_ASSIST_IMPORT( window ), assistant, page );
+			prepare_importdone( NACT_ASSISTANT_IMPORT( window ), assistant, page );
 			break;
 
 		default:
@@ -406,9 +406,9 @@ on_prepare( NactAssistant *window, GtkAssistant *assistant, GtkWidget *page )
 }
 
 static void
-prepare_confirm( NactAssistImport *window, GtkAssistant *assistant, GtkWidget *page )
+prepare_confirm( NactAssistantImport *window, GtkAssistant *assistant, GtkWidget *page )
 {
-	static const gchar *thisfn = "nact_assist_import_prepare_confirm";
+	static const gchar *thisfn = "nact_assistant_import_prepare_confirm";
 	g_debug( "%s: window=%p, assistant=%p, page=%p", thisfn, window, assistant, page );
 
 	gchar *text = g_strdup( _( "<b>About to import selected files :</b>\n\n" ));
@@ -431,9 +431,9 @@ prepare_confirm( NactAssistImport *window, GtkAssistant *assistant, GtkWidget *p
 }
 
 static void
-prepare_importdone( NactAssistImport *window, GtkAssistant *assistant, GtkWidget *page )
+prepare_importdone( NactAssistantImport *window, GtkAssistant *assistant, GtkWidget *page )
 {
-	static const gchar *thisfn = "nact_assist_import_prepare_importdone";
+	static const gchar *thisfn = "nact_assistant_import_prepare_importdone";
 	g_debug( "%s: window=%p, assistant=%p, page=%p", thisfn, window, assistant, page );
 
 	do_import( window, assistant );
@@ -491,9 +491,9 @@ prepare_importdone( NactAssistImport *window, GtkAssistant *assistant, GtkWidget
 }
 
 static void
-do_import( NactAssistImport *window, GtkAssistant *assistant )
+do_import( NactAssistantImport *window, GtkAssistant *assistant )
 {
-	static const gchar *thisfn = "nact_assist_import_do_import";
+	static const gchar *thisfn = "nact_assistant_import_do_import";
 	g_debug( "%s: window=%p", thisfn, window );
 
 	GtkWidget *chooser = gtk_assistant_get_nth_page( assistant, ASSIST_PAGE_FILES_SELECTION );
diff --git a/src/nact/nact-assistant-import.h b/src/nact/nact-assistant-import.h
new file mode 100644
index 0000000..efa1391
--- /dev/null
+++ b/src/nact/nact-assistant-import.h
@@ -0,0 +1,71 @@
+/*
+ * Nautilus Actions
+ * A Nautilus extension which offers configurable context menu actions.
+ *
+ * Copyright (C) 2005 The GNOME Foundation
+ * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009 Pierre Wieser and others (see AUTHORS)
+ *
+ * This Program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This Program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public
+ * License along with this Library; see the file COPYING.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place,
+ * Suite 330, Boston, MA 02111-1307, USA.
+ *
+ * Authors:
+ *   Frederic Ruaudel <grumz grumz net>
+ *   Rodrigo Moya <rodrigo gnome-db org>
+ *   Pierre Wieser <pwieser trychlos org>
+ *   ... and many others (see AUTHORS)
+ */
+
+#ifndef __NACT_ASSISTANT_IMPORT_H__
+#define __NACT_ASSISTANT_IMPORT_H__
+
+/*
+ * NactAssistantImport class definition.
+ */
+
+#include "nact-assistant.h"
+
+G_BEGIN_DECLS
+
+#define NACT_ASSISTANT_IMPORT_TYPE					( nact_assistant_import_get_type())
+#define NACT_ASSISTANT_IMPORT( object )				( G_TYPE_CHECK_INSTANCE_CAST( object, NACT_ASSISTANT_IMPORT_TYPE, NactAssistantImport ))
+#define NACT_ASSISTANT_IMPORT_CLASS( klass )		( G_TYPE_CHECK_CLASS_CAST( klass, NACT_ASSISTANT_IMPORT_TYPE, NactAssistantImportClass ))
+#define NACT_IS_ASSISTANT_IMPORT( object )			( G_TYPE_CHECK_INSTANCE_TYPE( object, NACT_ASSISTANT_IMPORT_TYPE ))
+#define NACT_IS_ASSISTANT_IMPORT_CLASS( klass )		( G_TYPE_CHECK_CLASS_TYPE(( klass ), NACT_ASSISTANT_IMPORT_TYPE ))
+#define NACT_ASSISTANT_IMPORT_GET_CLASS( object )	( G_TYPE_INSTANCE_GET_CLASS(( object ), NACT_ASSISTANT_IMPORT_TYPE, NactAssistantImportClass ))
+
+typedef struct NactAssistantImportPrivate NactAssistantImportPrivate;
+
+typedef struct {
+	NactAssistant               parent;
+	NactAssistantImportPrivate *private;
+}
+	NactAssistantImport;
+
+typedef struct NactAssistantImportClassPrivate NactAssistantImportClassPrivate;
+
+typedef struct {
+	NactAssistantClass               parent;
+	NactAssistantImportClassPrivate *private;
+}
+	NactAssistantImportClass;
+
+GType   nact_assistant_import_get_type( void );
+
+GSList *nact_assistant_import_run( NactWindow *main );
+
+G_END_DECLS
+
+#endif /* __NACT_ASSISTANT_IMPORT_H__ */
diff --git a/src/nact/nact-imenubar.c b/src/nact/nact-imenubar.c
index 1f4a11a..73705a9 100644
--- a/src/nact/nact-imenubar.c
+++ b/src/nact/nact-imenubar.c
@@ -35,8 +35,8 @@
 #include <glib/gi18n.h>
 
 #include "nact-application.h"
-#include "nact-assist-export.h"
-#include "nact-assist-import.h"
+#include "nact-assistant-export.h"
+#include "nact-assistant-import.h"
 #include "nact-imenubar.h"
 
 /* private interface data
@@ -755,7 +755,7 @@ on_tools_selected( GtkMenuItem *item, NactWindow *window )
 static void
 on_import_activated( GtkMenuItem *item, NactWindow *window )
 {
-	GSList *list = nact_assist_import_run( window );
+	GSList *list = nact_assistant_import_run( window );
 	GSList *ia;
 	for( ia = list ; ia ; ia = ia->next ){
 		add_action( window, NA_ACTION( ia->data ));
@@ -775,7 +775,7 @@ on_export_activated( GtkMenuItem *item, NactWindow *window )
 	static const gchar *thisfn = "nact_imenubar_on_export_activated";
 	g_debug( "%s: item=%p, window=%p", thisfn, item, window );
 
-	nact_assist_export_run( NACT_WINDOW( window ));
+	nact_assistant_export_run( NACT_WINDOW( window ));
 
 	/*g_assert( NACT_IS_MAIN_WINDOW( user_data ));
 	NactWindow *wndmain = NACT_WINDOW( user_data );



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/nact/nact-assist-export.h b/src/nact/nact-assistant-export.h
similarity index 63%
rename from src/nact/nact-assist-export.h
rename to src/nact/nact-assistant-export.h
index a0471fe..52bd2d1 100644
--- a/src/nact/nact-assist-export.h
+++ b/src/nact/nact-assistant-export.h
@@ -28,11 +28,11 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __NACT_ASSIST_EXPORT_H__
-#define __NACT_ASSIST_EXPORT_H__
+#ifndef __NACT_ASSISTANT_EXPORT_H__
+#define __NACT_ASSISTANT_EXPORT_H__
 
 /*
  * NactAssistExport class definition.
  *
  * Rationale:
  *
@@ -64,33 +64,33 @@
 
 G_BEGIN_DECLS
 
-#define NACT_ASSIST_EXPORT_TYPE					( nact_assist_export_get_type())
-#define NACT_ASSIST_EXPORT( object )			( G_TYPE_CHECK_INSTANCE_CAST( object, NACT_ASSIST_EXPORT_TYPE, NactAssistExport ))
-#define NACT_ASSIST_EXPORT_CLASS( klass )		( G_TYPE_CHECK_CLASS_CAST( klass, NACT_ASSIST_EXPORT_TYPE, NactAssistExportClass ))
-#define NACT_IS_ASSIST_EXPORT( object )			( G_TYPE_CHECK_INSTANCE_TYPE( object, NACT_ASSIST_EXPORT_TYPE ))
-#define NACT_IS_ASSIST_EXPORT_CLASS( klass )	( G_TYPE_CHECK_CLASS_TYPE(( klass ), NACT_ASSIST_EXPORT_TYPE ))
-#define NACT_ASSIST_EXPORT_GET_CLASS( object )	( G_TYPE_INSTANCE_GET_CLASS(( object ), NACT_ASSIST_EXPORT_TYPE, NactAssistExportClass ))
+#define NACT_ASSISTANT_EXPORT_TYPE					( nact_assistant_export_get_type())
+#define NACT_ASSISTANT_EXPORT( object )				( G_TYPE_CHECK_INSTANCE_CAST( object, NACT_ASSISTANT_EXPORT_TYPE, NactAssistantExport ))
+#define NACT_ASSISTANT_EXPORT_CLASS( klass )		( G_TYPE_CHECK_CLASS_CAST( klass, NACT_ASSISTANT_EXPORT_TYPE, NactAssistantExportClass ))
+#define NACT_IS_ASSISTANT_EXPORT( object )			( G_TYPE_CHECK_INSTANCE_TYPE( object, NACT_ASSISTANT_EXPORT_TYPE ))
+#define NACT_IS_ASSISTANT_EXPORT_CLASS( klass )		( G_TYPE_CHECK_CLASS_TYPE(( klass ), NACT_ASSISTANT_EXPORT_TYPE ))
+#define NACT_ASSISTANT_EXPORT_GET_CLASS( object )	( G_TYPE_INSTANCE_GET_CLASS(( object ), NACT_ASSISTANT_EXPORT_TYPE, NactAssistantExportClass ))
 
-typedef struct NactAssistExportPrivate NactAssistExportPrivate;
+typedef struct NactAssistantExportPrivate NactAssistantExportPrivate;
 
 typedef struct {
-	NactAssistant            parent;
-	NactAssistExportPrivate *private;
+	NactAssistant               parent;
+	NactAssistantExportPrivate *private;
 }
-	NactAssistExport;
+	NactAssistantExport;
 
-typedef struct NactAssistExportClassPrivate NactAssistExportClassPrivate;
+typedef struct NactAssistantExportClassPrivate NactAssistantExportClassPrivate;
 
 typedef struct {
-	NactAssistantClass            parent;
-	NactAssistExportClassPrivate *private;
+	NactAssistantClass               parent;
+	NactAssistantExportClassPrivate *private;
 }
-	NactAssistExportClass;
+	NactAssistantExportClass;
 
-GType nact_assist_export_get_type( void );
+GType nact_assistant_export_get_type( void );
 
-void  nact_assist_export_run( NactWindow *main );
+void  nact_assistant_export_run( NactWindow *main );
 
 G_END_DECLS
 
-#endif /* __NACT_ASSIST_EXPORT_H__ */
+#endif /* __NACT_ASSISTANT_EXPORT_H__ */
@@ -28,11 +28,11 @@
 
 /*
- * NactAssistExport class definition.
+ * NactAssistantExport class definition.
  *
  * Rationale: